Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Flipper-Zero/STM32CubeWB.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'Projects/P-NUCLEO-WB55.USBDongle/Applications/Thread/Thread_Coap_DataTransfer/STM32_WPAN/App/app_thread.c')
-rw-r--r--Projects/P-NUCLEO-WB55.USBDongle/Applications/Thread/Thread_Coap_DataTransfer/STM32_WPAN/App/app_thread.c32
1 files changed, 15 insertions, 17 deletions
diff --git a/Projects/P-NUCLEO-WB55.USBDongle/Applications/Thread/Thread_Coap_DataTransfer/STM32_WPAN/App/app_thread.c b/Projects/P-NUCLEO-WB55.USBDongle/Applications/Thread/Thread_Coap_DataTransfer/STM32_WPAN/App/app_thread.c
index be914cbc4..c0436a26c 100644
--- a/Projects/P-NUCLEO-WB55.USBDongle/Applications/Thread/Thread_Coap_DataTransfer/STM32_WPAN/App/app_thread.c
+++ b/Projects/P-NUCLEO-WB55.USBDongle/Applications/Thread/Thread_Coap_DataTransfer/STM32_WPAN/App/app_thread.c
@@ -4,18 +4,17 @@
* File Name : App/app_thread.c
* Description : Thread Application.
******************************************************************************
- * @attention
- *
- * <h2><center>&copy; Copyright (c) 2019 STMicroelectronics.
- * All rights reserved.</center></h2>
- *
- * This software component is licensed by ST under Ultimate Liberty license
- * SLA0044, the "License"; You may not use this file except in compliance with
- * the License. You may obtain a copy of the License at:
- * www.st.com/SLA0044
- *
- ******************************************************************************
- */
+ * @attention
+ *
+ * Copyright (c) 2019-2021 STMicroelectronics.
+ * All rights reserved.
+ *
+ * This software is licensed under terms that can be found in the LICENSE file
+ * in the root directory of this software component.
+ * If no LICENSE file comes with this software, it is provided AS-IS.
+ *
+ ******************************************************************************
+ */
/* USER CODE END Header */
/* Includes ------------------------------------------------------------------*/
@@ -472,7 +471,7 @@ static void APP_THREAD_TraceError(const char * pMess, uint32_t ErrCode)
/**
* @brief Check if the Coprocessor Wireless Firmware loaded supports Thread
- * and display associated informations
+ * and display associated information
* @param None
* @retval None
*/
@@ -573,9 +572,9 @@ static void APP_THREAD_SendNextBuffer(void)
}
else
{
/* Buffer transfer has been successfully transfered */
BSP_LED_On(LED1);
- APP_DBG("********* BUFFER HAS BEEN TRANFERED *********");
+ APP_DBG("********* BUFFER HAS BEEN TRANSFERRED *********");
}
}
@@ -1310,7 +1309,7 @@ void VCP_DataReceived(uint8_t* Buf , uint32_t *Len)
uint32_t char_remaining = 0;
static uint32_t len_total = 0;
- /* Copy the characteres in the temporary buffer */
+ /* Copy the characters in the temporary buffer */
for (i = 0; i < *Len; i++)
{
TmpString[len_total++] = Buf[i];
@@ -1338,4 +1337,3 @@ void VCP_DataReceived(uint8_t* Buf , uint32_t *Len)
/* USER CODE BEGIN FD_WRAP_FUNCTIONS */
/* USER CODE END FD_WRAP_FUNCTIONS */
-/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
@@ -573,9 +572,9 @@ static void APP_THREAD_SendNextBuffer(void)
else
{
- /* Buffer transfer has been successfully transfered */
+ /* Buffer transfer has been successfully transferred */
BSP_LED_On(LED1);